@@ -58,25 +58,32 @@ def getParametersList(filepath):
     return parameters_list
 
 
-def createEmptySheet(outputfilename):
+def createEmptySheet(outputfilename, copytemplatesheet):
     # Create a workbook and add a worksheet.
     filename = outputfilename
     if(not outputfilename.endswith('.xlsx')):
         filename = filename + '.xlsx'
 
-    #filename = apiName + '.xlsx'
     workbook = xlsxwriter.Workbook(filename)
     # worksheet = workbook.add_worksheet(apiName)
     workbook.close()
 
-    wb1 = xw.Book(templateFileName)
-    wb2 = xw.Book(filename)
+    if(copytemplatesheet):
 
-    ws1 = wb1.sheets['Mapping Template']
-    ws1.api.copy_worksheet(after_=wb2.sheets[0].api)
+        wb1 = xw.Book(templateFileName)
+        wb2 = xw.Book(filename)
 
-    wb2.save()
-    wb2.app.quit()
+        ws1 = wb1.sheets['Mapping Template']
+        ws1.api.copy_worksheet(after_=wb2.sheets[0].api)
+
+        wb2.save()
+        wb2.app.quit()
+
+    return True
+
+
+def checkIfTemplateFileExists():
+    return os.path.isfile(templateFileName)
 
 
 def getTypeCode(type_str):
@@ -113,7 +120,13 @@ def updateSheetWithData(filename, apiName, params):
 
 
 def generate_api_template_file(program, outputfile):
-    #api_name = input("Please enter API name: ")
+
+    if not program:
+        return '\033[91m' + "Error: Program name is missing" + '\033[0m'
+
+    if not outputfile:
+        return '\033[91m' + "Error: Output filename is missing" + '\033[0m'
+
     api_name = program
     filename = outputfile
     if(not outputfile.endswith('.xlsx')):
@@ -124,9 +137,18 @@ def generate_api_template_file(program, outputfile):
     if api_info is not None:
         #print(api_info)
         params = getParametersList(api_info[1])
-        createEmptySheet(filename)
+        createEmptySheet(filename, True)
         updateSheetWithData(filename, api_info[0], params)
         print(bcolors.OKGREEN + "File generated successfully" + bcolors.ENDC)
     else:
         print(bcolors.FAIL +
               "Error: API specifications file not found in directory 'api-files'. Please make sure that specifications file exits" + bcolors.ENDC)
+
+def getAPIProgramNames():
+    files = os.listdir(apiDirPath)
+    for filename in files:
+        file_path = os.path.join(apiDirPath, filename)
+        with open(file_path) as json_file:
+            data = json.load(json_file)
+            file_api_name = data['info']['title'].split()[0]
+            print("\'" + file_api_name + "\'" +',')
